@@ -18,7 +18,8 @@ var ParseError = errors.ParseError;
 var XMLReader = sax.XMLReader;
 
 /**
- * Normalizes line ending according to <https://www.w3.org/TR/xml11/#sec-line-ends>:
+ * Normalizes line ending according to <https://www.w3.org/TR/xml11/#sec-line-ends>,
+ * including some Unicode "newline" characters:
  *
  * > XML parsed entities are often stored in computer files which,
  * > for editing convenience, are organized into lines.
@@ -27,20 +28,21 @@ var XMLReader = sax.XMLReader;
  * >
  * > To simplify the tasks of applications, the XML processor must behave
  * > as if it normalized all line breaks in external parsed entities (including the document entity)
- * > on input, before parsing, by translating all of the following to a single #xA character:
+ * > on input, before parsing, by translating the following to a single #xA character:
  * >
  * > 1. the two-character sequence #xD #xA,
  * > 2. the two-character sequence #xD #x85,
  * > 3. the single character #x85,
  * > 4. the single character #x2028,
- * > 5. any #xD character that is not immediately followed by #xA or #x85.
+ * > 5. the single character #x2029,
+ * > 6. any #xD character that is not immediately followed by #xA or #x85.
  *
  * @param {string} input
  * @returns {string}
  * @prettierignore
  */
 function normalizeLineEndings(input) {
-	return input.replace(/\r[\n\u0085]/g, '\n').replace(/[\r\u0085\u2028]/g, '\n');
+	return input.replace(/\r[\n\u0085]/g, '\n').replace(/[\r\u0085\u2028\u2029]/g, '\n');
 }
 
 /**
@@ -63,7 +65,7 @@ function normalizeLineEndings(input) {
  * DEPRECATED! use `onError` instead.
  * @property {function(level:ErrorLevel, message:string, context: DOMHandler):void}
  * [onError]
- * A function that is invoked for every error that occurs during parsing.
+ * A function invoked for every error that occurs during parsing.
  *
  * If it is not provided, all errors are reported to `console.error`
  * and only `fatalError`s are thrown as a `ParseError`,
@@ -78,7 +80,9 @@ function normalizeLineEndings(input) {
  * attribute describing their location in the XML string.
  * Default is true.
  * @property {(string) => string} [normalizeLineEndings]
- * used to replace line endings before parsing, defaults to `normalizeLineEndings`
+ * used to replace line endings before parsing, defaults to exported `normalizeLineEndings`,
+ * which normalizes line endings according to <https://www.w3.org/TR/xml11/#sec-line-ends>,
+ * including some Unicode "newline" characters.
  * @property {Object} [xmlns]
  * The XML namespaces that should be assumed when parsing.
  * The default namespace can be provided by the key that is the empty string.
@@ -101,7 +105,10 @@ function normalizeLineEndings(input) {
  * @see https://html.spec.whatwg.org/multipage/dynamic-markup-insertion.html#dom-parsing-and-serialization
  */
 function DOMParser(options) {
-	options = options || { locator: true };
+	options = options || {};
+	if (options.locator === undefined) {
+		options.locator = true;
+	}
 
 	/**
 	 * The method to use instead of `conventions.assign`, which is used to copy values from
