@@ -381,6 +381,9 @@ var ATTLIST_DECL_START = '<!ATTLIST';
 // to support XML without namespaces in DTD we can not restrict it to QName
 var AttlistDecl = reg(ATTLIST_DECL_START, S, Name, AttDef, '*', S_OPT, '>');
 
+// https://html.spec.whatwg.org/multipage/urls-and-fetching.html#about:legacy-compat
+var ABOUT_LEGACY_COMPAT = 'about:legacy-compat';
+var ABOUT_LEGACY_COMPAT_SystemLiteral = regg('"' + ABOUT_LEGACY_COMPAT + '"', '|', "'" + ABOUT_LEGACY_COMPAT + "'");
 var SYSTEM = 'SYSTEM';
 var PUBLIC = 'PUBLIC';
 // https://www.w3.org/TR/xml11/#NT-ExternalID
@@ -494,6 +497,8 @@ exports.chars_without = chars_without;
 exports.detectUnicodeSupport = detectUnicodeSupport;
 exports.reg = reg;
 exports.regg = regg;
+exports.ABOUT_LEGACY_COMPAT = ABOUT_LEGACY_COMPAT;
+exports.ABOUT_LEGACY_COMPAT_SystemLiteral = ABOUT_LEGACY_COMPAT_SystemLiteral;
 exports.AttlistDecl = AttlistDecl;
 exports.CDATA_START = CDATA_START;
 exports.CDATA_END = CDATA_END;
