@@ -81,7 +81,7 @@ function parse(source, defaultNSMapCopy, entityMap, domBuilder, errorHandler) {
 		if (hasOwn(entityMap, k)) {
 			return entityMap[k];
 		} else if (k.charAt(0) === '#') {
-			return fixedFromCharCode(parseInt(k.substr(1).replace('x', '0x')));
+			return fixedFromCharCode(parseInt(k.substring(1).replace('x', '0x')));
 		} else {
 			errorHandler.error('entity not found:' + a);
 			return a;
@@ -98,20 +98,20 @@ function parse(source, defaultNSMapCopy, entityMap, domBuilder, errorHandler) {
 		}
 	}
 
+	var lineStart = 0;
+	var lineEnd = 0;
+	var linePattern = /\r\n?|\n|$/g;
+	var locator = domBuilder.locator;
+
 	function position(p, m) {
 		while (p >= lineEnd && (m = linePattern.exec(source))) {
-			lineStart = m.index;
-			lineEnd = lineStart + m[0].length;
+			lineStart = lineEnd;
+			lineEnd = m.index + m[0].length;
 			locator.lineNumber++;
 		}
 		locator.columnNumber = p - lineStart + 1;
 	}
 
-	var lineStart = 0;
-	var lineEnd = 0;
-	var linePattern = /.*(?:\r\n?|\n)|.*$/g;
-	var locator = domBuilder.locator;
-
 	var parseStack = [{ currentNSMap: defaultNSMapCopy }];
 	var unclosedTags = [];
 	var start = 0;
@@ -124,7 +124,7 @@ function parse(source, defaultNSMapCopy, entityMap, domBuilder, errorHandler) {
 				}
 				if (!source.substring(start).match(/^\s*$/)) {
 					var doc = domBuilder.doc;
-					var text = doc.createTextNode(source.substr(start));
+					var text = doc.createTextNode(source.substring(start));
 					if (doc.documentElement) {
 						return errorHandler.error('Extra content at the end of the document');
 					}
@@ -587,8 +587,10 @@ function _copy(source, target) {
  * @property {function(): string} substringFromIndex
  * creates a substring from the current index to the end of `source`
  * @property {function(compareWith: string): boolean} substringStartsWith
- * Checks if source contains `compareWith`,
- * starting from the current index.
+ * Checks if `source` contains `compareWith`, starting from the current index.
+ * @property {function(compareWith: string): boolean} substringStartsWithCaseInsensitive
+ * Checks if `source` contains `compareWith`, starting from the current index,
+ * comparing the upper case of both sides.
  * @see {@link parseUtils}
  */
 
@@ -634,6 +636,9 @@ function parseUtils(source, start) {
 	function substringStartsWith(text) {
 		return source.substring(index, index + text.length) === text;
 	}
+	function substringStartsWithCaseInsensitive(text) {
+		return source.substring(index, index + text.length).toUpperCase() === text.toUpperCase();
+	}
 
 	function getMatch(args) {
 		var expr = g.reg('^', args);
@@ -657,6 +662,7 @@ function parseUtils(source, start) {
 		skipBlanks: skipBlanks,
 		substringFromIndex: substringFromIndex,
 		substringStartsWith: substringStartsWith,
+		substringStartsWithCaseInsensitive: substringStartsWithCaseInsensitive,
 	};
 }
 
@@ -753,7 +759,7 @@ function parseDoctypeInternalSubset(p, errorHandler) {
 function parseDoctypeCommentOrCData(source, start, domBuilder, errorHandler, isHTML) {
 	var p = parseUtils(source, start);
 
-	switch (p.char(2)) {
+	switch (isHTML ? p.char(2).toUpperCase() : p.char(2)) {
 		case '-':
 			// should be a comment
 			var comment = p.getMatch(g.Comment);
@@ -782,7 +788,7 @@ function parseDoctypeCommentOrCData(source, start, domBuilder, errorHandler, isH
 			if (domBuilder.doc && domBuilder.doc.documentElement) {
 				return errorHandler.fatalError('Doctype not allowed inside or after documentElement at position ' + p.getIndex());
 			}
-			if (!p.substringStartsWith(g.DOCTYPE_DECL_START)) {
+			if (isHTML ? !p.substringStartsWithCaseInsensitive(g.DOCTYPE_DECL_START) : !p.substringStartsWith(g.DOCTYPE_DECL_START)) {
 				return errorHandler.fatalError('Expected ' + g.DOCTYPE_DECL_START + ' at position ' + p.getIndex());
 			}
 			p.skip(g.DOCTYPE_DECL_START.length);
@@ -800,6 +806,10 @@ function parseDoctypeCommentOrCData(source, start, domBuilder, errorHandler, isH
 			doctype.name = p.getMatch(g.Name);
 			if (!doctype.name)
 				return errorHandler.fatalError('doctype name missing or contains unexpected characters at position ' + p.getIndex());
+
+			if (isHTML && doctype.name.toLowerCase() !== 'html') {
+				errorHandler.warning('Unexpected DOCTYPE in HTML document at position ' + p.getIndex());
+			}
 			p.skipBlanks();
 
 			// Check for ExternalID
@@ -815,10 +825,26 @@ function parseDoctypeCommentOrCData(source, start, domBuilder, errorHandler, isH
 					doctype.publicId = match.groups.PubidLiteral;
 				}
 				p.skip(match[0].length);
+			} else if (isHTML && p.substringStartsWithCaseInsensitive(g.SYSTEM)) {
+				// https://html.spec.whatwg.org/multipage/syntax.html#doctype-legacy-string
+				p.skip(g.SYSTEM.length);
+				if (p.skipBlanks() < 1) {
+					return errorHandler.fatalError('Expected whitespace after ' + g.SYSTEM + ' at position ' + p.getIndex());
+				}
+				doctype.systemId = p.getMatch(g.ABOUT_LEGACY_COMPAT_SystemLiteral);
+				if (!doctype.systemId) {
+					return errorHandler.fatalError(
+						'Expected ' + g.ABOUT_LEGACY_COMPAT + ' in single or double quotes after ' + g.SYSTEM + ' at position ' + p.getIndex()
+					);
+				}
+			}
+			if (isHTML && doctype.systemId && !g.ABOUT_LEGACY_COMPAT_SystemLiteral.test(doctype.systemId)) {
+				errorHandler.warning('Unexpected doctype.systemId in HTML document at position ' + p.getIndex());
+			}
+			if (!isHTML) {
+				p.skipBlanks();
+				doctype.internalSubset = parseDoctypeInternalSubset(p, errorHandler);
 			}
-
-			p.skipBlanks();
-			doctype.internalSubset = parseDoctypeInternalSubset(p, errorHandler);
 			p.skipBlanks();
 			if (p.char() !== '>') {
 				return errorHandler.fatalError('doctype not terminated with > at position ' + p.getIndex());
