@@ -1,5 +1,6 @@
 'use strict';
 
+const { performance } = require('node:perf_hooks');
 const { describe, expect, test } = require('@jest/globals');
 const { DOMParser, XMLSerializer } = require('../lib');
 const { assign, MIME_TYPE, NAMESPACE } = require('../lib/conventions');
@@ -34,12 +35,26 @@ describe('DOMParser', () => {
 			};
 			expect(doc.documentElement).toMatchObject(expected);
 		});
-		test("should not use locator when it's not set in options", () => {
+		test("should use locator when it's not explicitly set to false in options", () => {
 			const options = {};
 			const it = new DOMParser(options);
 
 			const doc = it.parseFromString('<xml/>', MIME_TYPE.XML_TEXT);
 
+			const expected = {
+				columnNumber: 1,
+				lineNumber: 1,
+			};
+			expect(doc.documentElement).toMatchObject(expected);
+		});
+		test("should not use locator when it's set to false in options", () => {
+			const options = {
+				locator: false,
+			};
+			const it = new DOMParser(options);
+
+			const doc = it.parseFromString('<xml/>', MIME_TYPE.XML_TEXT);
+
 			expect(doc.documentElement).not.toHaveProperty('columnNumber');
 			expect(doc.documentElement).not.toHaveProperty('lineNumber');
 		});
@@ -309,6 +324,19 @@ describe('DOMParser', () => {
 			const doc = parser.parseFromString(source, MIME_TYPE.XML_TEXT);
 			expect(new XMLSerializer().serializeToString(doc)).toEqual(source);
 		});
+		test('should parse larger documents with Unicode whitespace with reasonable performance even when not using the default normalizeLineEndings', () => {
+			// issue: https://github.com/xmldom/xmldom/issues/838
+			const start = performance.now();
+			const onError = jest.fn();
+			const normalizeLineEndings = jest.fn((source) => source);
+			const { parser } = getTestParser({ onError, normalizeLineEndings });
+			const source = `<root>${'A'.repeat(15000)}\n${'A'.repeat(15000)}\u0085${'A'.repeat(15000)}\u2028${'A'.repeat(15000)}\u2029</root>`;
+			const doc = parser.parseFromString(source, MIME_TYPE.XML_TEXT);
+			expect(normalizeLineEndings).toHaveBeenCalledWith(source);
+			expect(new XMLSerializer().serializeToString(doc)).toEqual(source);
+			// jest config testTimeout seems to generally work, but counts less time than this method, so this assertion is required
+			expect(performance.now() - start).toBeLessThanOrEqual(500);
+		});
 	});
 });
 
