@@ -1,7 +1,9 @@
 'use strict';
 
+const { describe, expect, test } = require('@jest/globals');
 const { DOMParser, normalizeLineEndings } = require('../../lib/dom-parser');
 const { MIME_TYPE } = require('../../lib/conventions');
+
 const whitespaceToHex = (str) => str.replace(/\s/g, (c) => `#x${c.charCodeAt(0).toString(16)}`);
 
 describe('DOMParser constructor option normalizeLineEndings', () => {
@@ -41,6 +43,10 @@ describe('normalizeLineEndings', () => {
 		expect(whitespaceToHex(normalizeLineEndings('\u2028'))).toBe('#xa');
 	});
 
+	test('should normalize the single character #x2029', () => {
+		expect(whitespaceToHex(normalizeLineEndings('\u2029'))).toBe('#xa');
+	});
+
 	test('should normalize any #xD character that is not immediately followed by #xA or #x85', () => {
 		expect(whitespaceToHex(normalizeLineEndings('\r \n'))).toBe('#xa#x20#xa');
 		expect(whitespaceToHex(normalizeLineEndings(' \r\r'))).toBe('#x20#xa#xa');
